@@ -57,29 +57,37 @@ class RuntimeConfig(lime_admin.plugins.AdminPlugin):
         """
         defaultConfig = {
             "scriveHost": "https://lime.scrive.com",
-            "scriveClientCredentialsIdentifier": "",
-            "scriveClientCredentialsSecret": "",
-            "scriveTokenCredentialsIdentifier": "",
-            "scriveTokenCredentialsSecret": "",
+            "scriveCredentials": {
+                "apitoken": "",
+                "apisecret": "",
+                "accesstoken": "",
+                "accesssecret": ""
+            },
             "limeHost": "",
             "limeApiKey": ""
         }
+
         try:
             config = super().get_config()
+            
             if not "scriveHost" in config:
-                config["scriveHost"] = defaultConfig["scriveHost"]
-            if not "scriveClientCredentialsIdentifier" in config:
-                config["scriveClientCredentialsIdentifier"] = defaultConfig["scriveClientCredentialsIdentifier"]
-            if not "scriveClientCredentialsSecret" in config:
-                config["scriveClientCredentialsSecret"] = defaultConfig["scriveClientCredentialsSecret"]
-            if not "scriveTokenCredentialsIdentifier" in config:
-                config["scriveTokenCredentialsIdentifier"] = defaultConfig["scriveTokenCredentialsIdentifier"]
-            if not "scriveTokenCredentialsSecret" in config:
-                config["scriveTokenCredentialsSecret"] = defaultConfig["scriveTokenCredentialsSecret"]
+                config["scriveHost"] = {}
+            if not "scriveCredentials" in config:
+                config["scriveCredentials"] = defaultConfig["scriveCredentials"]
+            if not "apitoken" in config["scriveCredentials"]:
+                config["scriveCredentials"]["apitoken"] = defaultConfig["scriveCredentials"]["apitoken"]
+            if not "apisecret" in config["scriveCredentials"]:
+                config["scriveCredentials"]["apisecret"] = defaultConfig["scriveCredentials"]["apisecret"]
+            if not "accesstoken" in config["scriveCredentials"]:
+                config["scriveCredentials"]["accesstoken"] = defaultConfig["scriveCredentials"]["accesstoken"]
+            if not "accesssecret" in config["scriveCredentials"]:
+                config["scriveCredentials"]["accesssecret"] = defaultConfig["scriveCredentials"]["accesssecret"]
+
             if not "limeHost" in config:
                 config["limeHost"] = defaultConfig["limeHost"]
             if not "limeApiKey" in config:
                 config["limeApiKey"] = defaultConfig["limeApiKey"]
+
             return config
         except lime_admin.plugins.NotFoundError:
             return defaultConfig
@@ -114,7 +122,7 @@ class RuntimeConfig(lime_admin.plugins.AdminPlugin):
 
         try :
             url = config["scriveHost"] + '/api/config/'
-            x = requests.post(url, data = config)
+            x = requests.post(url, json = config)
             if x.status_code == 200:
                 super().set_config(config=config)
             else:
