@@ -7,7 +7,7 @@ import {
     LimeobjectsStateService
 } from '@limetech/lime-web-components-interfaces';
 import { Component, Element, h, Prop, State} from '@stencil/core';
-import { Configs, CurrentLimeobject, Limeobjects} from '@limetech/lime-web-components-decorators';
+import { Configs, CurrentLimeobject, Session } from '@limetech/lime-web-components-decorators';
 import { ListItem, ListSeparator, ValidationStatus, Tab} from '@limetech/lime-elements';
 
 type File = {
@@ -27,6 +27,10 @@ export class Test implements LimeWebComponent {
     @State()
     private document : any = {}
 
+    @Session()
+    @State()
+    private session: any = {};
+
     @Prop()
     public platform: LimeWebComponentPlatform;
 
@@ -46,7 +50,8 @@ export class Test implements LimeWebComponent {
 
     private goToScrive(id) {
         const host = this.config.limepkg_scrive.scriveHost;
-        window.open(`${host}/public/?limeDocId=${id}${ this.includePerson ? "&usePerson=true" : ""}`);
+        const lang = this.session.language;
+        window.open(`${host}/public/?limeDocId=${id}&lang=${lang}${ this.includePerson ? "&usePerson=true" : ""}`);
     }
     
     
@@ -73,24 +78,18 @@ export class Test implements LimeWebComponent {
             return;
         }
 
+        const translate = this.platform.get(PlatformServiceName.Translate);
+        const label = translate.get("limepkg_scrive.primary_action")
+
         return (
-            <div>
-                <limel-collapsible-section header="Sign with Scrive">
-                    <limel-button
-                        label={`Design Contract`}
-                        outlined={true}
-                        onClick={() =>
-                            this.goToScrive(this.context.id)
-                        }
-                    />
-                    <limel-checkbox
-                        label="Add associated person as signing party"
-                        id="fab"
-                        checked={this.includePerson}
-                        required={false}
-                        onChange={() => this.includePerson = !this.includePerson}
-                    />
-                </limel-collapsible-section>
+            <div class="container">
+                <limel-button
+                    label={label}
+                    outlined={true}
+                    onClick={() =>
+                        this.goToScrive(this.context.id)
+                    }
+                />
             </div>
         );
     }
